Welcome to Geolocate’s documentation! — Geolocate 1.3.0 documentation

# Welcome to Geolocate’s documentation!

## Packages:

- geolocate.classes package

## Scripts:

- glocate.py

This script is the launcher for Geolocate and scans given text to find urls and IP addresses. The output is the same text but every url and IP address is going to have its geolocation appended.

Geolocate is possible thanks to Maxmind GeoIP database and their API.

`geolocate.glocate.` `main`()

`geolocate.glocate.` `print_lines_parsed`(parser)

# Indices and tables

- Index
- Module Index
- Search Page